@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.757';
+our $VERSION = '1.758';
 
 use Exporter qw( import );
 
@@ -330,8 +330,8 @@ sub table_char_width { [
 [   0xeb2,    0xeb3, 1],
 [   0xeb4,    0xebc, 0],
 [   0xebd,    0xec7, 1],
-[   0xec8,    0xecd, 0],
-[   0xece,    0xf17, 1],
+[   0xec8,    0xece, 0],
+[   0xecf,    0xf17, 1],
 [   0xf18,    0xf19, 0],
 [   0xf1a,    0xf34, 1],
 [   0xf35,    0xf35, 0],
@@ -885,7 +885,9 @@ sub table_char_width { [
 [ 0x10d24,  0x10d27, 0],
 [ 0x10d28,  0x10eaa, 1],
 [ 0x10eab,  0x10eac, 0],
-[ 0x10ead,  0x10f45, 1],
+[ 0x10ead,  0x10efc, 1],
+[ 0x10efd,  0x10eff, 0],
+[ 0x10f00,  0x10f45, 1],
 [ 0x10f46,  0x10f50, 0],
 [ 0x10f51,  0x10f81, 1],
 [ 0x10f82,  0x10f85, 0],
@@ -933,7 +935,9 @@ sub table_char_width { [
 [ 0x11236,  0x11237, 0],
 [ 0x11238,  0x1123d, 1],
 [ 0x1123e,  0x1123e, 0],
-[ 0x1123f,  0x112de, 1],
+[ 0x1123f,  0x11240, 1],
+[ 0x11241,  0x11241, 0],
+[ 0x11242,  0x112de, 1],
 [ 0x112df,  0x112df, 0],
 [ 0x112e0,  0x112e2, 1],
 [ 0x112e3,  0x112ea, 0],
@@ -1055,9 +1059,19 @@ sub table_char_width { [
 [ 0x11d97,  0x11d97, 0],
 [ 0x11d98,  0x11ef2, 1],
 [ 0x11ef3,  0x11ef4, 0],
-[ 0x11ef5,  0x1342f, 1],
-[ 0x13430,  0x13438, 0],
-[ 0x13439,  0x16aef, 1],
+[ 0x11ef5,  0x11eff, 1],
+[ 0x11f00,  0x11f01, 0],
+[ 0x11f02,  0x11f35, 1],
+[ 0x11f36,  0x11f3a, 0],
+[ 0x11f3b,  0x11f3f, 1],
+[ 0x11f40,  0x11f40, 0],
+[ 0x11f41,  0x11f41, 1],
+[ 0x11f42,  0x11f42, 0],
+[ 0x11f43,  0x1342f, 1],
+[ 0x13430,  0x13440, 0],
+[ 0x13441,  0x13446, 1],
+[ 0x13447,  0x13455, 0],
+[ 0x13456,  0x16aef, 1],
 [ 0x16af0,  0x16af4, 0],
 [ 0x16af5,  0x16b2f, 1],
 [ 0x16b30,  0x16b36, 0],
@@ -1084,9 +1098,13 @@ sub table_char_width { [
 [ 0x1affd,  0x1affe, 2],
 [ 0x1afff,  0x1afff, 1],
 [ 0x1b000,  0x1b122, 2],
-[ 0x1b123,  0x1b14f, 1],
+[ 0x1b123,  0x1b131, 1],
+[ 0x1b132,  0x1b132, 2],
+[ 0x1b133,  0x1b14f, 1],
 [ 0x1b150,  0x1b152, 2],
-[ 0x1b153,  0x1b163, 1],
+[ 0x1b153,  0x1b154, 1],
+[ 0x1b155,  0x1b155, 2],
+[ 0x1b156,  0x1b163, 1],
 [ 0x1b164,  0x1b167, 2],
 [ 0x1b168,  0x1b16f, 1],
 [ 0x1b170,  0x1b2fb, 2],
@@ -1130,13 +1148,17 @@ sub table_char_width { [
 [ 0x1e023,  0x1e024, 0],
 [ 0x1e025,  0x1e025, 1],
 [ 0x1e026,  0x1e02a, 0],
-[ 0x1e02b,  0x1e12f, 1],
+[ 0x1e02b,  0x1e08e, 1],
+[ 0x1e08f,  0x1e08f, 0],
+[ 0x1e090,  0x1e12f, 1],
 [ 0x1e130,  0x1e136, 0],
 [ 0x1e137,  0x1e2ad, 1],
 [ 0x1e2ae,  0x1e2ae, 0],
 [ 0x1e2af,  0x1e2eb, 1],
 [ 0x1e2ec,  0x1e2ef, 0],
-[ 0x1e2f0,  0x1e8cf, 1],
+[ 0x1e2f0,  0x1e4eb, 1],
+[ 0x1e4ec,  0x1e4ef, 0],
+[ 0x1e4f0,  0x1e8cf, 1],
 [ 0x1e8d0,  0x1e8d6, 0],
 [ 0x1e8d7,  0x1e943, 1],
 [ 0x1e944,  0x1e94a, 0],
@@ -1206,8 +1228,8 @@ sub table_char_width { [
 [ 0x1f6d0,  0x1f6d2, 2],
 [ 0x1f6d3,  0x1f6d4, 1],
 [ 0x1f6d5,  0x1f6d7, 2],
-[ 0x1f6d8,  0x1f6dc, 1],
-[ 0x1f6dd,  0x1f6df, 2],
+[ 0x1f6d8,  0x1f6db, 1],
+[ 0x1f6dc,  0x1f6df, 2],
 [ 0x1f6e0,  0x1f6ea, 1],
 [ 0x1f6eb,  0x1f6ec, 2],
 [ 0x1f6ed,  0x1f6f3, 1],
@@ -1223,24 +1245,20 @@ sub table_char_width { [
 [ 0x1f946,  0x1f946, 1],
 [ 0x1f947,  0x1f9ff, 2],
 [ 0x1fa00,  0x1fa6f, 1],
-[ 0x1fa70,  0x1fa74, 2],
-[ 0x1fa75,  0x1fa77, 1],
-[ 0x1fa78,  0x1fa7c, 2],
+[ 0x1fa70,  0x1fa7c, 2],
 [ 0x1fa7d,  0x1fa7f, 1],
-[ 0x1fa80,  0x1fa86, 2],
-[ 0x1fa87,  0x1fa8f, 1],
-[ 0x1fa90,  0x1faac, 2],
-[ 0x1faad,  0x1faaf, 1],
-[ 0x1fab0,  0x1faba, 2],
-[ 0x1fabb,  0x1fabf, 1],
-[ 0x1fac0,  0x1fac5, 2],
-[ 0x1fac6,  0x1facf, 1],
-[ 0x1fad0,  0x1fad9, 2],
-[ 0x1fada,  0x1fadf, 1],
-[ 0x1fae0,  0x1fae7, 2],
-[ 0x1fae8,  0x1faef, 1],
-[ 0x1faf0,  0x1faf6, 2],
-[ 0x1faf7,  0x1ffff, 1],
+[ 0x1fa80,  0x1fa88, 2],
+[ 0x1fa89,  0x1fa8f, 1],
+[ 0x1fa90,  0x1fabd, 2],
+[ 0x1fabe,  0x1fabe, 1],
+[ 0x1fabf,  0x1fac5, 2],
+[ 0x1fac6,  0x1facd, 1],
+[ 0x1face,  0x1fadb, 2],
+[ 0x1fadc,  0x1fadf, 1],
+[ 0x1fae0,  0x1fae8, 2],
+[ 0x1fae9,  0x1faef, 1],
+[ 0x1faf0,  0x1faf8, 2],
+[ 0x1faf9,  0x1ffff, 1],
 [ 0x20000,  0x2fffd, 2],
 [ 0x2fffe,  0x2ffff, 1],
 [ 0x30000,  0x3fffd, 2],
